@@ -5,8 +5,8 @@ import pulumi
 
 def storage_account(stem, props, resource_group, provider=None, parent=None, depends_on=None):
     sa = storage.StorageAccount(
-        f'sa-{stem}',
-        account_name=f'sa-{stem}',
+        f'sa{stem}',
+        account_name=f'sa{stem}',
         resource_group_name= resource_group,
         tags=props.tags,
         location=props.location,
